@@ -3,7 +3,7 @@
 /**
   * SquirrelMail Compose Extras Plugin
   *
-  * Copyright (c) 2005-2011 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2005-2012 Paul Lesniewski <paul@squirrelmail.org>
   * Copyright (c) 2003-2004 Justus Pendleton <justus@ryoohki.net>
   * Copyright (c) 2003 Bruce Richardson <itsbruce@uklinux.net>
   *
@@ -15,7 +15,8 @@
   */
 
 global $ce_limit_submit, $ce_disable_recipient_fields,
-       $allow_acceses_keys, $ce_prevent_enter_causing_submit;
+       $ce_default_subject_warning, $allow_acceses_keys,
+       $ce_prevent_enter_causing_submit;
 
 
 
@@ -29,6 +30,18 @@ $ce_limit_submit = 1;
 
 
 
+// By default, should a blank subject cause a warning to
+// pop up?  Users can change this setting, but this will
+// serve as the default.  Consider user annoyance versus
+// forgetfulness when choosing a value here.
+//
+//    0 = no
+//    1 = yes
+//
+$ce_default_subject_warning = 0;
+
+
+
 // Should users be forced to use the address book to add
 // recipients?  If this is enabled, users won't be able to
 // type anything directly into the To, Cc and Bcc fields
