@@ -4,7 +4,7 @@
 /**
   * SquirrelMail Compose Extras Plugin
   *
-  * Copyright (c) 2005-2011 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2005-2012 Paul Lesniewski <paul@squirrelmail.org>
   * Copyright (c) 2003-2004 Justus Pendleton <justus@ryoohki.net>
   * Copyright (c) 2003 Bruce Richardson <itsbruce@uklinux.net>
   *
@@ -24,7 +24,7 @@
   *                 configuration error for this plugin.
   *
   */
-function compose_extras_check_configuration_do()
+function compose_extras_check_configuration()
 {
 
    // make sure base config is available
@@ -71,10 +71,10 @@ function compose_extras_init()
   * Integrate options into SM options page
   *
   */
-function ce_show_options_do($args)
+function ce_show_options($args)
 {
 
-   global $allow_acceses_keys;
+   global $allow_acceses_keys, $ce_default_subject_warning;
    compose_extras_init();
 
    $hook_name = get_current_hook_name($args);
@@ -109,6 +109,7 @@ function ce_show_options_do($args)
    global $data_dir, $username;
    $tabs = getPref($data_dir, $username, 'fix_compose_tabs', 1);
    $insert_lines_in_reply_body = getPref($data_dir, $username, 'insert_lines_in_reply_body', 2);
+   $subject_warning = getPref($data_dir, $username, 'subject_warning', $ce_default_subject_warning);
    $rewrap_compose_body = getPref($data_dir, $username, 'rewrap_compose_body', 1);
    $remove_citation_button = getPref($data_dir, $username, 'remove_citation_button', 0);
 
@@ -140,6 +141,14 @@ function ce_show_options_do($args)
                                5 => 5),
    );
 
+   $optpage_data['vals'][$rewrapIndex][] = array(
+      'name'          => 'subject_warning',
+      'caption'       => _("Warn When Sending Without A Subject"),
+      'type'          => SMOPT_TYPE_BOOLEAN,
+      'initial_value' => $subject_warning,
+      'refresh'       => SMOPT_REFRESH_NONE,
+   );
+
    $optpage_data['vals'][$rewrapIndex][] = array(
       'name'          => 'rewrap_compose_body',
       'caption'       => _("Show Rewrap Compose Body Button"),
@@ -342,12 +351,12 @@ function ce_show_options_do($args)
   * Inserts javascript for tab fixes (and more)
   *
   */
-function ce_compose_bottom_do()
+function ce_compose_bottom()
 {
 
    global $username, $data_dir, $javascript_on, $allow_acceses_keys,
           $ce_limit_submit, $ce_disable_recipient_fields,
-          $ce_prevent_enter_causing_submit;
+          $ce_prevent_enter_causing_submit, $ce_default_subject_warning;
 
 
    compose_extras_init();
@@ -427,11 +436,27 @@ function ce_compose_bottom_do()
    if ($tabs == 1 || $tabs == 2) 
    {
 
-      global $submit_button_name;
+      global $location_of_buttons, $submit_button_name, $use_custom_from_tab_order;
+
+      // if the Custom From plugin is in use and enabled by the user,
+      // we need a slightly different tab ordering
+      //
+      $use_custom_from_tab_order = FALSE;
+      global $plugins;
+      if (in_array('custom_from', $plugins))
+      {
+         include_once(SM_PATH . 'plugins/custom_from/functions.php');
+         if (custom_from_is_allowed_and_is_enabled($username))
+            $use_custom_from_tab_order = TRUE;
+      }
+
       if (check_sm_version(1, 5, 2))
          $submit_button_name = 'send1';
       else
-         $submit_button_name = 'send';
+         if ($location_of_buttons == 'bottom')
+            $submit_button_name = 'send';
+         else
+            $submit_button_name = 'send[1]';
 
       if (check_sm_version(1, 5, 2))
       {
@@ -456,8 +481,8 @@ function ce_compose_bottom_do()
    //
    if ($allow_acceses_keys && !check_sm_version(1, 5, 2))
    {
-      global $accesskey_compose_identity, $accesskey_compose_to,
-             $accesskey_compose_cc, $accesskey_compose_bcc,
+      global $location_of_buttons, $submit_button_name, $accesskey_compose_identity,
+             $accesskey_compose_to, $accesskey_compose_cc, $accesskey_compose_bcc,
              $accesskey_compose_subject, $accesskey_compose_priority,
              $accesskey_compose_on_read, $accesskey_compose_on_delivery,
              $accesskey_compose_signature, $accesskey_compose_addresses,
@@ -482,6 +507,14 @@ function ce_compose_bottom_do()
       $accesskey_compose_attach = getPref($data_dir, $username, 'accesskey_compose_attach', 'h');      
       $accesskey_compose_delete_attach = getPref($data_dir, $username, 'accesskey_compose_delete_attach', 'l');  
 
+      if (check_sm_version(1, 5, 2))
+         $submit_button_name = 'send1';
+      else
+         if ($location_of_buttons == 'bottom')
+            $submit_button_name = 'send';
+         else
+            $submit_button_name = 'send[1]';
+
       global $t;
       $t = array(); // no need to put config vars herein, they are already globalized
       include_once(SM_PATH . 'plugins/compose_extras/templates/default/accesskeys.tpl');
@@ -512,6 +545,37 @@ function ce_compose_bottom_do()
    }
 
 
+   // function that checks for an empty subject
+   //
+   if (getPref($data_dir, $username, 'subject_warning', $ce_default_subject_warning))
+   {
+
+      global $subject_warning_text;
+      sq_change_text_domain('compose_extras');
+      $subject_warning_text = _("Warning: You did not enter a subject.\\n\\nSend without a subject?");
+
+
+      if (check_sm_version(1, 5, 2))
+      {
+         global $t;
+         $t = array(); // no need to put config vars herein, they are already globalized
+         ob_start();
+         include_once(SM_PATH . 'plugins/compose_extras/templates/default/subject_warning.tpl');
+         $output .= ob_get_contents();
+         ob_end_clean();
+      }
+      else
+      {
+         global $t;
+         $t = array(); // no need to put config vars herein, they are already globalized
+         include_once(SM_PATH . 'plugins/compose_extras/templates/default/subject_warning.tpl');
+      }
+
+      sq_change_text_domain('squirrelmail');
+
+   }
+
+
    // prevent Enter from causing form submit from input text fields?
    //
    if ($ce_prevent_enter_causing_submit)
@@ -546,30 +610,55 @@ function ce_compose_bottom_do()
 
 
 /**
-  * Adjusts body text as needed
+  * Adjusts body text as needed and add checks
+  * to the page submit action (subject warning
+  * and prevent multiple form submit)
   *
   */
-function ce_fix_body_do()
+function ce_fix_body()
 {
 
    global $username, $data_dir, $ce_limit_submit, $compose_onsubmit,
-          $action;
+          $action, $ce_default_subject_warning;
+   $onsubmit = array();
 
 
    compose_extras_init();
 
 
    // stop user from being able to double-click submit button
+   // (IMPORTANT that this comes BEFORE the subject warning)
    //
    if ($ce_limit_submit)
    {
+      $text = ' if (!submitOnlyOnce()) return false; ';
+
       if (check_sm_version(1, 4, 21))
-         $compose_onsubmit[] = ' if (!submitOnlyOnce()) return false; ';
+         $compose_onsubmit[] = $text;
       else
-         echo ' onsubmit="return submitOnlyOnce();" ';
+         $onsubmit[] = $text;
    }
 
 
+   // optionally warn user if sending without a subject
+   //
+   if (getPref($data_dir, $username, 'subject_warning', $ce_default_subject_warning))
+   {
+      $text = ' if (!check_subject()) {submit_count = 0; return false; } ';
+
+      if (check_sm_version(1, 4, 21))
+         $compose_onsubmit[] = $text;
+      else
+         $onsubmit[] = $text;
+   }
+
+
+   // pre-1.4.21
+   //
+   if (!empty($onsubmit))
+      echo ' onsubmit="' . implode('', $onsubmit) . '" ';
+
+
    // in 1.5.2+, $action is already figured out and in the global scope
    // otherwise (1.4.x), get from the POST/GET
    //
@@ -598,10 +687,13 @@ function ce_fix_body_do()
 
 
 /**
-  * Include JavaScript that accomplishes the rewrap functionality
+  * Include JavaScript that accomplishes the rewrap functionality.
+  * Also, make sure this plugin comes before all others on the
+  * compose_form hook so it can prevent other onsubmit handlers
+  * from firing multiple times.
   *
   */
-function rewrap_add_script_do($args)
+function rewrap_add_script($args)
 {
 
    // only need to bother when we are on the compose page
@@ -656,7 +748,7 @@ function rewrap_add_script_do($args)
   * Add the "Rewrap" button to the compose screen
   *
   */
-function rewrap_add_button_do()
+function rewrap_add_button()
 {
 
    // only need to bother when javascript is activated/in use
